==> dino-im_0.1.0.orig.tar.gz: dino-0.1.0/README.md <==
![Dino](https://dino.im/img/readme_header.svg)
=======

![screenshots](https://dino.im/img/screenshot-main.png)

Installation
------------
Have a look at the [prebuilt packages](https://github.com/dino/dino/wiki/Distribution-Packages).

Build
-----
Make sure to install all [dependencies](https://github.com/dino/dino/wiki/Build#dependencies).

    ./configure
    make
    build/dino

Resources
---------
- Check out the [Dino website](https://dino.im).
- Join our XMPP conference room at `chat@dino.im`.
- The [wiki](https://github.com/dino/dino/wiki) provides additional information.

Contribute
----------
- Pull requests are welcome. Please discuss bigger changes in the conference room first.
- Look at [how to debug](https://github.com/dino/dino/wiki/Debugging) Dino before you report a bug.
- Help [translating](https://hosted.weblate.org/projects/dino/) Dino into your language.

License
-------
    Dino - Modern Jabber/XMPP Client using GTK+/Vala
    Copyright (C) 2016-2020 Dino contributors

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

==> dino-im_0.2.0.orig.tar.gz: dino-0.2.0/README.md <==
![Dino](https://dino.im/img/readme_header.svg)
=======

![screenshots](https://dino.im/img/screenshot-main.png)

Installation
------------
Have a look at the [prebuilt packages](https://github.com/dino/dino/wiki/Distribution-Packages).

Build
-----
Make sure to install all [dependencies](https://github.com/dino/dino/wiki/Build#dependencies).

    ./configure
    make
    build/dino

Resources
---------
- Check out the [Dino website](https://dino.im).
- Join our XMPP channel at `chat@dino.im`.
- The [wiki](https://github.com/dino/dino/wiki) provides additional information.

Contribute
----------
- Pull requests are welcome. [These](https://github.com/dino/dino/issues?q=is%3Aopen+is%3Aissue+label%3A%22good+first+issue%22) might be good first issues. Please discuss bigger changes in our channel first.
- Look at [how to debug](https://github.com/dino/dino/wiki/Debugging) Dino before you report a bug.
- Help [translating](https://github.com/dino/dino/wiki/Translations) Dino into your language.
- Make a [donation](https://dino.im/#donate).

License
-------
    Dino - Modern Jabber/XMPP Client using GTK+/Vala
    Copyright (C) 2016-2020 Dino contributors

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
